import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import aws_cdk.assets._jsii
import aws_cdk.aws_cloudwatch._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_kms._jsii
import aws_cdk.aws_logs._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.aws_s3_assets._jsii
import aws_cdk.aws_ssm._jsii
import aws_cdk.cloud_assembly_schema._jsii
import aws_cdk.core._jsii
import aws_cdk.cx_api._jsii
import aws_cdk.region_info._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/aws-ec2", "1.61.0", __name__[0:-6], "aws-ec2@1.61.0.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
